@@ -108,7 +108,7 @@
 */
 #define	GKRELLM_VERSION_MAJOR	1
 #define	GKRELLM_VERSION_MINOR	2
-#define	GKRELLM_VERSION_REV		9
+#define	GKRELLM_VERSION_REV		11
 /* Backward compatibility */
 #define	VERSION_MAJOR			GKRELLM_VERSION_MAJOR
 #define	VERSION_MINOR			GKRELLM_VERSION_MINOR
@@ -649,6 +649,7 @@ typedef struct
 	DecalButton	*button;
 	GtkTooltips	*tooltip;
 	gchar		*tooltip_comment;
+	Decal		*decal;		/* Used if DECAL_LAUNCHER type	*/
 	}
 	Launcher;
 
@@ -740,18 +741,20 @@ typedef struct
 /* ------------------------ */
 
 
-/* ================= Theme Config ==================*/
 
 #define	CHART_PANEL_TYPE	0
 #define	METER_PANEL_TYPE	1
 #define	N_PANEL_TYPES		2
 
+#define	PANEL_LAUNCHER		CHART_PANEL_TYPE
+#define	METER_LAUNCHER		METER_PANEL_TYPE
+#define	DECAL_LAUNCHER		3
+
 #define	DEFAULT_STYLE_ID	0
 /* Old one */
 #define	DEFAULT_STYLE		0
 
 
-
 /* Style names for the builtin monitors.  Define them globally so plugins
 |  can lookup a builtin style_id.  These names are used as subdirectory
 |  names under the current theme where monitor specific images are located.
